@@ -1,7 +1,8 @@
 from siuba.sql import LazyTbl
+from sqlalchemy.engine import Inspector
 
-from .sql import get_engine
 from .config import is_development
+from .sql import get_engine
 
 
 class AttributeDict:
@@ -45,7 +46,8 @@ class AutoTable:
             del self.__dict__[k]
 
         # initialize ----
-        self._table_names = tuple(self._engine.table_names())
+        insp = Inspector(self._engine)
+        self._table_names = tuple(insp.get_table_names()) + tuple(insp.get_view_names())
 
         mappings = {}
         for name in self._table_names:
@@ -111,10 +113,10 @@ class TableFactory:
             """
 
 
-tbl = AutoTable(
+tbls = AutoTable(
     get_engine(),
     lambda s: s,  # s.replace(".", "_"),
     lambda s: "zzz_test_" not in s if not is_development() else True,
 )
 
-tbl._init()
+tbls._init()
